@@ -1,4 +1,5 @@
 import logging
+from typing import List
 from urllib.parse import urljoin
 
 from .types import PaddleJsonType
@@ -14,8 +15,8 @@ def add_modifier(
     modifier_description: str = '',
 ) -> dict:
     """
-    https://developer.paddle.com/api-reference/subscription-api/modifiers/createmodifier
-    """
+    `Add Modifier Paddle docs <https://developer.paddle.com/api-reference/subscription-api/modifiers/createmodifier>`_
+    """  # NOQA: E501
     url = urljoin(self.vendors_v2, 'subscription/modifiers/create')
 
     json = {
@@ -29,8 +30,8 @@ def add_modifier(
 
 def delete_modifier(self, modifier_id: int) -> dict:
     """
-    https://developer.paddle.com/api-reference/subscription-api/modifiers/deletemodifier
-    """
+    `Delete Modifier Paddle docs <https://developer.paddle.com/api-reference/subscription-api/modifiers/deletemodifier>`_
+    """  # NOQA: E501
     url = urljoin(self.vendors_v2, 'subscription/modifiers/delete')
     return self.post(url=url, json={'modifier_id': modifier_id})
 
@@ -39,10 +40,10 @@ def list_modifiers(
     self,
     subscription_id: int = None,
     plan_id: int = None
-) -> dict:
-    """
-    https://developer.paddle.com/api-reference/subscription-api/modifiers/listmodifiers
+) -> List[dict]:
     """
+    `List Modifiers Paddle docs <https://developer.paddle.com/api-reference/subscription-api/modifiers/listmodifiers>`_
+    """  # NOQA: E501
     url = urljoin(self.vendors_v2, 'subscription/modifiers')
 
     json = {
