@@ -1,5 +1,5 @@
 import logging
-from typing import Union
+from typing import List, Union
 from urllib.parse import urljoin
 
 from .types import DateType, PaddleJsonType
@@ -16,10 +16,10 @@ def list_subscription_payments(
     _from: DateType = None,
     to: DateType = None,
     is_one_off_charge: bool = None,
-) -> dict:
-    """
-    https://developer.paddle.com/api-reference/subscription-api/payments/listpayments
+) -> List[dict]:
     """
+    `List Payment (subscription) Paddle docs <https://developer.paddle.com/api-reference/subscription-api/payments/listpayments>`_
+    """  # NOQA: E501
     url = urljoin(self.vendors_v2, 'subscription/payments')
 
     json = {
@@ -41,10 +41,10 @@ def reschedule_subscription_payment(
     self,
     payment_id: int,
     date: DateType,
-) -> dict:
-    """
-    https://developer.paddle.com/api-reference/subscription-api/payments/updatepayment
+) -> bool:
     """
+    `Reschedule Payment (subscription) Paddle docs <https://developer.paddle.com/api-reference/subscription-api/payments/updatepayment>`_
+    """  # NOQA: E501
     url = urljoin(self.vendors_v2, 'subscription/payments_reschedule')
 
     json = {
